@@ -65,11 +65,22 @@ public:
      * @return the new current player.
      */
     Player& nextNonEmptyPlayer();
+    /**
+     * Accessor to the dealer player.
+     * @return the current dealer.
+     * @throw KardsGTError if no player is found to be the dealer.
+     */
+    Player& dealer();
     /**
      * Accessor to the current player.
      * @return the current player.
      */
     Player& currentPlayer();
+    /**
+     * Accessor to the current player's index.
+     * @return the current player's index.
+     */
+    int currentPlayerIndex() const;
     /**
      * Accessor to the player that is to the right of the current player.
      * @return the right player.
