@@ -415,7 +415,12 @@ void Cribbage::roundOver()
         m_players[i].setTurn(false);
     restoreHands();
     if (! hasAPlayerWonTheRound())
+    {
         score();
+        m_pInterface->crib->setFaceUp(false);
+        m_pInterface->player1Cards->setFaceUp(false);
+        m_pInterface->updateTable();
+    }
     m_pInterface->playerDiscards->clear(); // We have a delay setup, and so we need to clear the play sequence here.
     // See if anyone won the stake
     for (int i=0; i < m_players.size(); ++i)
@@ -527,10 +532,6 @@ void Cribbage::score()
         m_pInterface->displayRoundSummary(m_players[m_dealerIndex].name() + "'s Crib", m_cardSummary, m_messageSummary);
     else
         m_pInterface->promptMessage(m_players[m_dealerIndex].name() + "'s Crib", "Has nineteen.");
-    m_pInterface->updateTable();
-    m_pInterface->crib->setFaceUp(m_scoringCrib);
-    m_pInterface->player1Cards->setFaceUp(false);
-    m_pInterface->updateTable();
 }
 
 void Cribbage::scoring(Player &player, const CardProperties &cardProperties)
@@ -546,7 +547,7 @@ void Cribbage::scoring(Player &player, const CardProperties &cardProperties)
     points+=scorePairs(cardProperties);
     points+=scoreRuns(cardProperties);
     points+=scoreFlush(cardProperties);
-    points+=scoreNobs(player);
+    points+=scoreNobs(cardProperties);
     if (points > 0)
     {
         player.addPoint(points);
@@ -752,15 +753,18 @@ int Cribbage::scoreFlush(const CardProperties &cardProperties)
     return points;
 }
 
-int Cribbage::scoreNobs(const Player &player)
+int Cribbage::scoreNobs(const CardProperties &cardProperties)
 {
-    // The last card is the crib card in a players hand
-    for (int i=0; i < player.hand().size() - 1; ++i)
-        if (player.hand()[i].rank() == Card::JACK)
-            if (player.hand()[i].suit() == m_starter.suit())
+    CardSequence hand = cardProperties.sequence();
+
+    // Find nobs
+    for (int i=0, size = hand.size() - 1; i < size; ++i)
+        if ((hand[i].rank() == Card::JACK) && (hand[i] != m_starter))
+            if (hand[i].suit() == m_starter.suit())
             {
                 CardSequence nobs;
-                nobs.addCard(player.hand()[i]);
+
+                nobs.addCard(hand[i]);
                 m_cardSummary.push_back(nobs);
                 m_messageSummary.push_back(QString("%1 for his nobs").arg(CribbageRules::NOBS));
                 return CribbageRules::NOBS;
