@@ -14,9 +14,9 @@ using std::string;
 
 /// @param fileFilter is the filter for saved games for KardsGT.
 const QString KardsGTInterfaceBase::fileFilter = tr("KardsGT game files (*.kgf)\n" "All files (*)");
-/// @param VERSION is the current version of our programme.
+/// @param VERSION is the current version of our programme. @note Defined in main.cpp
 extern const string VERSION;
-/// @param COPYRIGHT is the current copyright years.
+/// @param COPYRIGHT is the current copyright years. @note Defined in main.cpp
 extern const string COPYRIGHT_YEARS;
 
 /**
@@ -50,8 +50,8 @@ void KardsGTInterfaceBase::destroy()
  */
 void KardsGTInterfaceBase::helpHandbook()
 {
-//    assistant->showPage("src/doc/toc.html");
-    assistant->showPage(QString("/usr/share/doc/kardsgt-%1/toc.html").arg(VERSION));
+    assistant->showPage("src/doc/toc.html");
+//     assistant->showPage(QString("/usr/share/doc/kardsgt-%1/toc.html").arg(VERSION));
 }
 
 /**
@@ -125,6 +125,11 @@ void KardsGTInterfaceBase::newGame()
         closeOpenGame();
         turnOnWar();
     }
+    else if (gamePlayed == "euchre")
+    {
+        closeOpenGame();
+        turnOnEuchre();
+    }
     else if (gamePlayed == "hearts")
     {
         closeOpenGame();
@@ -250,6 +255,7 @@ void KardsGTInterfaceBase::setActions(bool actionOn)
     gameCloseAction->setEnabled(actionOn);
     // En/disable games available.
     gameSelectCribbageAction->setEnabled(! actionOn);
+    gameSelectEuchreAction->setEnabled(! actionOn);
     gameSelectHeartsAction->setEnabled(! actionOn);
     gameSelectOld_MaidAction->setEnabled(! actionOn);
     gameSelectSpadesAction->setEnabled(! actionOn);
@@ -257,6 +263,8 @@ void KardsGTInterfaceBase::setActions(bool actionOn)
     // Toggle on/off the game we're playing
     if ((! actionOn) && gameSelectCribbageAction->isOn())
         gameSelectCribbageAction->setOn(actionOn);
+    if ((! actionOn) && gameSelectEuchreAction->isOn())
+        gameSelectEuchreAction->setOn(actionOn);
     if ((! actionOn) && gameSelectHeartsAction->isOn())
         gameSelectHeartsAction->setOn(actionOn);
     if ((! actionOn) && gameSelectOld_MaidAction->isOn())
@@ -298,6 +306,11 @@ void KardsGTInterfaceBase::selectGameAction(const QString &game)
         gameSelectSpadesAction->setOn(true);
         gamePlayed="spades";
     }
+    else if (game == "euchre")
+    {
+        gameSelectEuchreAction->setOn(true);
+        gamePlayed="euchre";
+    }
     else
         gamePlayed="unknown";
 }
@@ -358,12 +371,23 @@ void KardsGTInterfaceBase::turnOnSpades()
 }
 
 
+/**
+ * This sets up and starts a game of Old Maid.
+ */
 void KardsGTInterfaceBase::turnOnOldMaid()
 {
     selectGameAction("old maid");
     setupGame();
 }
 
+void KardsGTInterfaceBase::turnOnEuchre()
+{
+    selectGameAction("euchre");
+    setupGame();
+}
 
+/**
+ * This when implemented adjusts the settings for KardsGT.
+ */
 void KardsGTInterfaceBase::settingsConfigureKardsGT()
 {}
