@@ -32,6 +32,7 @@
 #include "oldmaidplayer.h"
 #include "spadesplayer.h"
 #include "warplayer.h"
+#include "euchreplayer.h"
 
 #include <qstring.h>
 
@@ -136,6 +137,12 @@ bool PlayerFactory::setupGamePlayer(const QString &game)
         m_players.back()->setName(m_ais.back()->name());
         m_players.back()->setLevel(m_ais.back()->skillLevel("war"));
     }
+    else if (game == "euchre")
+    {
+        m_players.push_back(new EuchrePlayer(*m_ais.back()));
+        m_players.back()->setName(m_ais.back()->name());
+        m_players.back()->setLevel(m_ais.back()->skillLevel("euchre"));
+    }
     else
         return false;
     return true;
